Documentation — pycodata 0.3.0 documentation

# Documentation

## pycodata

Python wrapper of the (Modern Fortran) codata library.

All attributes of the C extension `pycodata._codata` are directly available in the python wrapper.

## _codata

C extension wrapping the (Modern Fortran) codata constants.

pycodata._codata.as_dict()

  as_dict() –> dict

  Return all constants available in a dictionnary

pycodata._codata.get_number_constants()

  get_bumber_constants() –> int

  Get the number of constants.

pycodata._codata.get_uncertainty()

  get_uncertainty(name) –> float

  Get the uncertainty of the constant defined by name. If not found returns NaN

pycodata._codata.get_unit()

  get_unit(name) –> float

  Get the unit of the constant defined by name. If not found returns “None”

pycodata._codata.get_value()

  get_value(name) –> float

  Get the value of the constant defined by name. If not found returns NaN

pycodata._codata.get_year()

  get_year() –> str

  Get the revision year for the codata constants.

pycodata._codata.print()

  print() –> None

  Print all codata constants.